"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_framework_1 = require("@ionic/cli-framework");
const cli_utils_1 = require("@ionic/cli-utils");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_1 = require("@ionic/cli-utils/lib/errors");
const integrations_1 = require("@ionic/cli-utils/lib/integrations");
class IntegrationsDisableCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'disable',
                type: 'project',
                description: 'Disable an integration',
                inputs: [
                    {
                        name: 'name',
                        description: `The integration to disable (${integrations_1.INTEGRATION_NAMES.map(i => chalk_1.default.green(i)).join(', ')})`,
                        validators: [cli_framework_1.validators.required, cli_framework_1.contains(integrations_1.INTEGRATION_NAMES, {})],
                    },
                ],
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const [name] = inputs;
            if (!cli_utils_1.isIntegrationName(name)) {
                throw new errors_1.FatalException(`Don't know about ${chalk_1.default.green(name)} integration!`);
            }
            const integration = yield integrations_1.BaseIntegration.createFromName(this.env, name);
            const integrationConfig = yield integration.getConfig();
            try {
                if (!integrationConfig || integrationConfig.enabled === false) {
                    this.env.log.info(`Integration ${chalk_1.default.green(integration.name)} already disabled.`);
                }
                else {
                    yield integration.disable();
                    this.env.log.ok(`Integration ${chalk_1.default.green(integration.name)} disabled!`);
                }
            }
            catch (e) {
                if (e instanceof errors_1.Exception) {
                    throw new errors_1.FatalException(e.message);
                }
                throw e;
            }
            yield this.env.project.save();
        });
    }
}
exports.IntegrationsDisableCommand = IntegrationsDisableCommand;
